@@ -136,7 +136,7 @@ def download_rinex(station: str, year: int, month: int, day: int, rate: str = 'l
         saves crx version for Rinex3 downloads. Otherwise they are deleted.
     """
 
-    print('starting a new tag')
+    #print('starting a new tag')
 
 #   make sure environment variables exist.  set to current directory if not
     g.check_environ_variables()
@@ -148,7 +148,9 @@ def download_rinex(station: str, year: int, month: int, day: int, rate: str = 'l
     month, day, doy, cyyyy, cyy, cdoy = g.ymd2ch(year,month,day)
 
     # allowed archives, rinex 2.11
-    archive_list = ['sopac', 'unavco', 'sonel', 'cddis', 'nz', 'ga', 'bkg', 'jeff', 'ngs', 'nrcan', 'special', 'bev', 'all']
+    # unavco2 is for testing
+    archive_list = ['sopac', 'unavco', 'sonel', 'cddis', 'nz', 'ga', 
+            'bkg', 'jeff', 'ngs', 'nrcan', 'special', 'bev', 'all','unavco2']
 
 
     # removed the all archive
