@@ -10,13 +10,15 @@ import sys
 import subprocess
 import wget
 from urllib.parse import urlparse
+# local libraries
 import gnssrefl.gps as g
 import gnssrefl.cddis_highrate as ch
+import gnssrefl.kelly as kelly
 
 def gogetit(dir1, filename, ext):
     """
-    the purpose of this function is to to download RINEX 2 files
-    code will try to get the file and chck to see if it was successful
+    The purpose of this function is to to download RINEX 2 files.
+    The code will try to get the file and check to see if it was successful.
 
     Parameters
     ----------
@@ -58,12 +60,12 @@ def swapRS(stream):
     Parameters
     ----------
     stream : str
-         RINEX 3 file streaming acronym (S or R)
+        RINEX 3 filename streaming acronym (S or R)
 
     Returns
     -------
     newstream : str
-         the opposite of what was in stream
+        the opposite of what was in stream
 
     """
     if stream == 'R':
@@ -75,7 +77,7 @@ def swapRS(stream):
 def just_bkg(cyyyy, cdoy, file_name):
     """
 
-    looks for bkg rinex files in two directories
+    looks for RINEX files at BKG in two directories
 
     Parameters
     ----------
@@ -358,7 +360,7 @@ def universal_all(station9ch, year, doy, srate,stream):
 
 def rinex2names(station,year,doy):
     """
-    rinex2 filename 
+    Creates the expected filename for rinex2 version files
 
     Parameters
     ----------
@@ -411,6 +413,7 @@ def universal_rinex2(station, year, doy, archive):
         filename that was downloaded
 
     foundit : boolean
+        whether file was found
 
     """
     # define the file name
@@ -438,6 +441,14 @@ def universal_rinex2(station, year, doy, archive):
         foundit, file_name = gogetit(dir1, dname, '.Z'); 
         if not foundit:
             foundit, file_name = gogetit(dir1, oname, '.Z')
+    elif (archive == 'unavco2'):
+        print('testing out new protocol at unavco')
+        url1 = 'https://data-idm.unavco.org/archive/gnss/rinex/obs/' + cydoy + dname + '.Z'
+        foundit,file_name = kelly.the_kelly_simple_way(url1,dname + '.Z')
+        if not foundit:
+            url2 = 'https://data-idm.unavco.org/archive/gnss/rinex/obs/' + cydoy + oname + '.Z'
+            foundit,file_name = kelly.the_kelly_way(url2,oname + '.Z')
+
     elif (archive == 'special'):
         dir1 = 'https://data.unavco.org/archive/gnss/products/reflectometry/' + cydoy
         foundit, file_name = gogetit(dir1, oname, '.gz'); 
@@ -467,8 +478,12 @@ def universal_rinex2(station, year, doy, archive):
         dir1 = 'https://gnss.bev.gv.at/at.gv.bev.dc/data/obs/' + cydoy
         foundit, file_name = gogetit(dir1, dname, '.gz');
     elif (archive == 'jeff'):
-        dir1 = 'ftp://gps.alaska.edu/pub/gpsdata/permanent/C2/' + cydoy
-        foundit, file_name = gogetit(dir1, oname, '.gz');
+        if station == 'pbay':
+            dir1 = 'ftp://gps.alaska.edu/pub/gpsdata/permanent/C2/' + cydoy
+            foundit, file_name = gogetit(dir1, oname, '.gz');
+        else:
+            dir1 = 'ftp://gps.alaska.edu/pub/gpsdata/CoopCORS/' + cydoy + '/' + station.upper() + '/'
+            foundit, file_name = gogetit(dir1, oname, '.gz');
     elif (archive == 'ngs'):
         dir1 = 'https://geodesy.noaa.gov/corsdata/rinex/' + cydoy + '/' + station + '/'
         foundit, file_name = gogetit(dir1, oname, '.gz');
@@ -500,7 +515,7 @@ def universal_rinex2(station, year, doy, archive):
 
 def make_rinex2_ofiles(file_name):
     """
-    take a rinex2 file gunzip or uncompress and 
+    take a rinex2 file, gunzip or uncompress it, and 
     then Hatanaka decompress it
 
     Parameters
@@ -599,7 +614,6 @@ def rinex2_highrate(station, year, doy,archive,strip_snr):
 
     Parameters
     ----------
-
     station : string
          4 character station ID.  lowercase
 
@@ -610,8 +624,10 @@ def rinex2_highrate(station, year, doy,archive,strip_snr):
         day of year
 
     archive : string
+        name of GNSS archive
 
     strip_snr : boolean
+        whether you want to strip out the observables (leaving only SNR)
 
     """
     foundit = False
