@@ -26,7 +26,7 @@ def parse_arguments():
     parser.add_argument("-e1",  default=None, type=int, help="lower limit elevation angle (default is 5 deg) ")
     parser.add_argument("-e2",  default=None, type=int, help="upper limit elevation angle (default is 25 deg)")
     parser.add_argument("-h1",  default=None, type=float, help="lower limit reflector height (default is 0.5m) ")
-    parser.add_argument("-h2",  default=None, type=float, help="upper limit reflector height (default is 6 m)")
+    parser.add_argument("-h2",  default=None, type=float, help="upper limit reflector height (default is 8 m)")
     parser.add_argument("-azim1",  default=None, type=float, help="lower limit azimuth (default is 0 deg)")
     parser.add_argument("-azim2",  default=None, type=float, help="upper limit azimuth (default is 360 deg)")
     parser.add_argument("-sat", default=None, type=int, help="satellite")
@@ -48,7 +48,7 @@ def parse_arguments():
 
 def quicklook(station: str, year: int, doy: int,
               snr: int = 66, fr: int = 1, ampl: float = 7.,
-              e1: int = 5, e2: int = 25, h1: float = 0.5, h2: float = 6., sat: int = None,
+              e1: int = 5, e2: int = 25, h1: float = 0.5, h2: float = 8., sat: int = None,
               peak2noise: float = 3., screenstats: bool = False, fortran: bool = None, 
               plt: bool = True, azim1: float = 0., azim2: float = 360., ediff: float = 2.0):
     """
@@ -147,7 +147,6 @@ def quicklook(station: str, year: int, doy: int,
     if exitS:
         sys.exit()
 
-
     # set some reasonable default values for LSP (Reflector Height calculation).
     # most of these can be overriden at the command line
     if fr is not type(list):
@@ -167,6 +166,16 @@ def quicklook(station: str, year: int, doy: int,
             'e2': e2, 'minH': h1, 'maxH': h2, 'PkNoise': peak2noise, 'satsel': sat, 'fortran': fortran, 'pele': pele,
             'pltscreen': pltscreen, 'screenstats': screenstats, 'azim1': azim1, 'azim2': azim2, 'ediff': ediff}
 
+    deltaRH = h2-h1
+    if (deltaRH <= 0):
+        print('Your reflector height region is invalid (i.e. h1 is greater than h2). h1:', h1, ' h2: ',h2)
+        print('Exiting')
+        sys.exit()
+
+    if (deltaRH < 5.5):
+        print('The reflector height region must be at least 5.5 meters long. These values are used for computing ')
+        print('a valid periodogram and for quality control.  Change h1 or h2 or both. Exiting')
+        sys.exit()
     return quick.quickLook_function(**args)
     # returns two variables: data, datakey = quick.quicklook_function(**args)
 
