@@ -17,103 +17,11 @@ import gnssrefl.gps as g
 import gnssrefl.rinex2snr as rinex
 
 
-def read_snr_simple(obsfile):
-    """
-    Loads the data from a SNR file into memory 
-
-    Parameters
-    ----------
-    obsfile : string
-        name of the SNR file
-
-    Returns
-    -------
-    allGood :  int
-        one for all is well, zero is for all is bad
-    sat : numpy array of floats
-        satellite numbers
-    ele  : numpy array of floats
-        elevation angle (deg)
-    azi : numpy array of float 
-        azimuth (deg)
-    t  : numpy array of floats
-        seconds of the day (no leap seconds)
-    edot : numpy array of floats
-        derivative of elevation angle wrt time deg/sec
-    s1 : numpy array of floats
-        L1 SNR
-    s2 : numpy array of floats 
-        L2 SNR
-    s5 :  numpy array of floats 
-        L5 SNR
-    s6 :  numpy array of floats
-        L6 SNR
-    s7 :  numpy array of floats
-        L7 SNR 
-    s8 :  numpy array of floats
-        L8 SNR
-    snrE : numpy array of booleans 
-        whether SNR exists 
-
-    """
-#   defaults so all returned vectors have something stored in them
-    sat=[]; ele =[]; azi = []; t=[]; edot=[]; s1=[];
-    s2=[]; s5=[]; s6=[]; s7=[]; s8=[];
-    snrE = np.array([False, True, True,False,False,True,True,True,True],dtype = bool)
-#   
-    allGood = 1
-    try:
-        f = np.genfromtxt(obsfile,comments='%')
-        r,c = f.shape
-        # put in a positive elev mask
-        i= f[:,1] > 0
-        f=f[i,:]
-
-        #print('read_snr_simple, Number of rows:', r, ' Number of columns:',c)
-        sat = f[:,0]; ele = f[:,1]; azi = f[:,2]; t =  f[:,3]
-        edot =  f[:,4]; s1 = f[:,6]; s2 = f[:,7]; s6 = f[:,5]
-        # 
-        s1 = np.power(10,(s1/20))  
-        s2 = np.power(10,(s2/20))  
-        s6 = s6/20; s6 = np.power(10,s6)  
-#   make sure s5 has default value?
-        s5 = []
-        if c > 8:
-            s5 = f[:,8]
-            if (sum(s5) > 0):
-                s5 = s5/20; s5 = np.power(10,s5)  
-            #print(len(s5))
-        if c > 9:
-            s7 = f[:,9]
-            if (sum(s7) > 0):
-                s7 = np.power(10,(s7/20))  
-            else:
-                s7 = []
-        if c > 10:
-            s8 = f[:,10]
-            if (sum(s8) > 0):
-                s8 = np.power(10,(s8/20))  
-            else:
-                s8 = []
-        if (np.sum(s5) == 0):
-            snrE[5] = False; #print('no s5 data')
-        if (np.sum(s6) == 0):
-            #print('no s6 data'); 
-            snrE[6] = False
-        if (np.sum(s7) == 0):
-           # print('no s7 data'); 
-            snrE[7] = False
-        if (np.sum(s8) == 0):
-            snrE[8] = False; # print('no s8 data')
-    except:
-        print('problem reading the SNR file')
-        allGood = 0
-    return allGood, sat, ele, azi, t, edot, s1, s2, s5, s6, s7, s8, snrE
-
-
 def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pele,satsel,PkNoise,fortran,pltscreen,azim1,azim2,ediff,**kwargs):
     """
-    takes in all users inputs and calculates reflector heights. Makes png files.
+    This is the main function to compute spectral characteristics of a SNR file.
+    It takes in all user inputs and calculates reflector heights. It makes two png files to summarize
+    the data.
 
     Parameters
     ----------
@@ -156,7 +64,10 @@ def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pel
 
     """
 
-    #print('ediff',ediff)
+    if ((maxH - minH) < 5.5):
+        print('Requested reflector heights (', minH, ',', maxH, ') are too close together. ')
+        print('They must be at least 5.5 meters apart - and preferably further than that. Exiting')
+        return
 
     screenstats = kwargs.get('screenstats',False)
     if screenstats:
@@ -222,7 +133,7 @@ def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pel
                 dkfjaklj = True
             else:
                 print('>>>> The SNR the file needs does not exist ',obsfile)
-                print('Please us rinex2snr to make a SNR file')
+                print('Please use rinex2snr to make a SNR file')
                 sys.exit()
     allGood,sat,ele,azi,t,edot,s1,s2,s5,s6,s7,s8,snrE = read_snr_simple(obsfile)
     # this just means the file existed ... not that it had the frequency you want to use
@@ -232,6 +143,7 @@ def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pel
         rhout = open(quicklog,'w+')
         amax = 0
         minEdataset = np.min(ele)
+
         sats = sat 
         # very rare that no GPS data exist, so will not check it.  I will probably regret this
         #if (f < 6):
@@ -260,6 +172,8 @@ def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pel
             plt.figure(figsize=(10,6))
         allpoints = 0
 
+        # try to normalize the periodogram yaxes
+        axisSize =np.empty(shape=[0, 2])
 
         for a in range(naz):
             if pltscreen:
@@ -292,20 +206,24 @@ def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pel
                     #print('ALL tracks: Azim {0:5.1f} Satellite {1:2.0f} UTC {2:5.2f} Npts {3:3.0f} between Azimuths {4:3.0f}-{5:3.0f}'.format( avgAzim,satNu,UTCtime,Nv, az1, az2))
                 if Nv > minNumPts:
                     maxF, maxAmp, eminObs, emaxObs,riseSet,px,pz= g.strip_compute(x,y,cf,maxH,desiredP,polyV,minH) 
-                    nij =   pz[(px > NReg[0]) & (px < NReg[1])]
-                    Noise = 0
                     iAzim = int(avgAzim)
+                    Noise = 1
+                    if maxF == 0:
+                        print('invalid LSP')
+                        tooclose = True
+                    else:
+                        nij =   pz[(px > NReg[0]) & (px < NReg[1])]
                     # 2022 march 26
                     # introduce boolean for RH peaks that are too close to the edges of the RH periodogram
-                    tooclose = False
-                    if (abs(maxF - minH) < 0.05):
-                        tooclose = True
-                    if (abs(maxF - maxH) < 0.05):
-                        tooclose = True 
-                    if (len(nij) > 0):
-                        Noise = np.mean(nij)
-                    else:
-                        Noise = 1;  iAzim = 0 # i think this is set to zero so something down the line doesn't fail
+                        tooclose = False
+                        if (abs(maxF - minH) < 0.05):
+                            tooclose = True
+                        if (abs(maxF - maxH) < 0.05):
+                            tooclose = True 
+                        if (len(nij) > 0):
+                            Noise = np.mean(nij)
+                        else:
+                            Noise = 1;  iAzim = 0 # i think this is set to zero so something down the line doesn't fail
                     # add azimuth constraints. default is 0-360
                     if (not tooclose) & (delT < delTmax) & (eminObs < (e1 + ediff)) & (emaxObs > (e2 - ediff)) & (maxAmp > requireAmp) & (maxAmp/Noise > PkNoise) & (iAzim >= azim1) & (iAzim <= azim2):
                         T = g.nicerTime(UTCtime)
@@ -318,6 +236,9 @@ def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pel
                         datakey[idc][satNu] = [avgAzim, maxF, satNu,f,maxAmp,maxAmp/Noise, UTCtime]
                         if screenstats:
                             print('SUCCESS for Azimu {0:5.1f} Satellite {1:2.0f} UTC {2:5.2f} RH {3:7.3f} PkNoise {4:6.2f}'.format( avgAzim,satNu,UTCtime,maxF,maxAmp/Noise))
+                        # try to track the maximum amplitude in each quadrant this way
+                        newl=[a,maxAmp]
+                        axisSize =np.append(axisSize,[newl], axis=0)
 
                     else:
                         # these are failed tracks
@@ -350,12 +271,30 @@ def quickLook_function(station, year, doy, snr_type,f,e1,e2,minH,maxH,reqAmp,pel
                 plt.yticks(fontsize=fs)
 
         rhout.close()
+        setA = False # want to set the axes based on good retrieval amplitudes
+        # this boolean set when it finds such a quadrant
         if pltscreen:
-            d1=ax1.get_ylim() ; d2=ax2.get_ylim() ; d3=ax3.get_ylim() ; d4=ax4.get_ylim()
-            minv = min([d1[0], d2[0], d3[0], d4[0]])
-            maxv = max([d1[1], d2[1], d3[1], d4[1]])
-            ax1.set_ylim(minv,maxv) ; ax2.set_ylim(minv,maxv) ;
-            ax3.set_ylim(minv,maxv) ; ax4.set_ylim(minv,maxv)
+            maxv=2
+            for q in range(0,4):
+                ii = (axisSize[:,0] == q)
+                thisquad = axisSize[ii,1]
+                if len(thisquad) > 0:
+                    # found at least one good periodogram in this quadrant
+                    setA = True
+                    maxv = max(max(thisquad), maxv)
+            maxv = maxv*1.1
+            if setA:
+                ax1.set_ylim(0,maxv) ; ax2.set_ylim(0,maxv) ;
+                ax3.set_ylim(0,maxv) ; ax4.set_ylim(0,maxv)
+
+            else:
+            # old way was often dominated by bad retrievals
+            # but if no good retrievals ... 
+                d1=ax1.get_ylim() ; d2=ax2.get_ylim() ; d3=ax3.get_ylim() ; d4=ax4.get_ylim()
+                minv = min([d1[0], d2[0], d3[0], d4[0]])
+                maxv = max([d1[1], d2[1], d3[1], d4[1]])
+                ax1.set_ylim(minv,maxv) ; ax2.set_ylim(minv,maxv) ;
+                ax3.set_ylim(minv,maxv) ; ax4.set_ylim(minv,maxv)
 
         #print('preliminary reflector height results are stored in a file called logs/rh.txt')
         # this file seems to have an empty line at the end.  i do not know why.
@@ -487,5 +426,98 @@ def goodbad(fname,station,year,doy,h1,h2,PkNoise,reqAmp,freq,e1,e2):
     print('plot saved to ', f)
     plt.savefig(f)
 
+def read_snr_simple(obsfile):
+    """
+    Loads the data from a SNR file into memory 
 
+    Parameters
+    ----------
+    obsfile : string
+        name of the SNR file
 
+    Returns
+    -------
+    allGood :  int
+        one for all is well, zero is for all is bad
+    sat : numpy array of floats
+        satellite numbers
+    ele  : numpy array of floats
+        elevation angle (deg)
+    azi : numpy array of float 
+        azimuth (deg)
+    t  : numpy array of floats
+        seconds of the day (no leap seconds)
+    edot : numpy array of floats
+        derivative of elevation angle wrt time deg/sec
+    s1 : numpy array of floats
+        L1 SNR
+    s2 : numpy array of floats 
+        L2 SNR
+    s5 :  numpy array of floats 
+        L5 SNR
+    s6 :  numpy array of floats
+        L6 SNR
+    s7 :  numpy array of floats
+        L7 SNR 
+    s8 :  numpy array of floats
+        L8 SNR
+    snrE : numpy array of booleans 
+        whether SNR exists 
+
+    """
+#   defaults so all returned vectors have something stored in them
+    sat=[]; ele =[]; azi = []; t=[]; edot=[]; s1=[];
+    s2=[]; s5=[]; s6=[]; s7=[]; s8=[];
+    snrE = np.array([False, True, True,False,False,True,True,True,True],dtype = bool)
+#   
+    allGood = 1
+    try:
+        f = np.genfromtxt(obsfile,comments='%')
+        r,c = f.shape
+        # put in a positive elev mask
+        #print(np.min(f[:,1]))
+        i= f[:,1] > 0
+        f=f[i,:]
+
+        #print('read_snr_simple, Number of rows:', r, ' Number of columns:',c)
+        sat = f[:,0]; ele = f[:,1]; azi = f[:,2]; t =  f[:,3]
+        edot =  f[:,4]; s1 = f[:,6]; s2 = f[:,7]; s6 = f[:,5]
+        #print(np.min(ele))
+        # 
+        s1 = np.power(10,(s1/20))  
+        s2 = np.power(10,(s2/20))  
+        s6 = s6/20; s6 = np.power(10,s6)  
+#   make sure s5 has default value?
+        s5 = []
+        if c > 8:
+            s5 = f[:,8]
+            if (sum(s5) > 0):
+                s5 = s5/20; s5 = np.power(10,s5)  
+            #print(len(s5))
+        if c > 9:
+            s7 = f[:,9]
+            if (sum(s7) > 0):
+                s7 = np.power(10,(s7/20))  
+            else:
+                s7 = []
+        if c > 10:
+            s8 = f[:,10]
+            if (sum(s8) > 0):
+                s8 = np.power(10,(s8/20))  
+            else:
+                s8 = []
+        if (np.sum(s5) == 0):
+            snrE[5] = False; #print('no s5 data')
+        if (np.sum(s6) == 0):
+            #print('no s6 data'); 
+            snrE[6] = False
+        if (np.sum(s7) == 0):
+           # print('no s7 data'); 
+            snrE[7] = False
+        if (np.sum(s8) == 0):
+            snrE[8] = False; # print('no s8 data')
+    except:
+        print('problem reading the SNR file')
+        allGood = 0
+    #print('min e', min(ele))
+    return allGood, sat, ele, azi, t, edot, s1, s2, s5, s6, s7, s8, snrE
