@@ -124,6 +124,9 @@ def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,arc
 
     """
     #
+    if archive == 'special':
+        print('The special option needs to be updated for new UNAVCO/Earthscope protocols. Please contact')
+        print('Tim Dittmann or Kelly Enloe at Earthscope if your file download does not work.')
     # do not allow illegal skipit values
     if skipit < 1:
         skipit = 1
@@ -144,6 +147,8 @@ def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,arc
         station9ch = station.upper()
         if not mk:
             station = station[0:4].lower()
+        else:
+            station = station[0:4].upper()
     else:
         print('Illegal station input - Station must have 4,6,or 9 characters. Exiting')
         sys.exit()
@@ -190,11 +195,16 @@ def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,arc
             if (not illegal_day) and (not snre):
                 r = station + cdoy + '0.' + cyy + 'o'
                 rgz = station + cdoy + '0.' + cyy + 'o.gz'
+                localpath2 =  os.environ['REFL_CODE'] + '/' + cyyyy + '/rinex/' + station + '/'
                 if nol:
-                    print('Will assume RINEX file ', station, ' year:', year, ' doy:', doy, 'is in the local directory')
+                    print('Will first assume RINEX file ', station, ' year:', year, ' doy:', doy, 'is in the local directory')
                     # this assumes RINEX file is in local directory or "nearby"
                     if version == 2:
-                        the_makan_option(station,cyyyy,cyy,cdoy) # looks everywhere in your local directories
+                        if mk:
+                            the_makan_option(station,cyyyy,cyy,cdoy) # looks everywhere in your local directories
+                        if not os.path.exists(r):
+                            # could try this way? - look for file in localpath2. gunzip if necessary
+                            allgood = get_local_rinexfile(r,localpath2)
                         if os.path.exists(r):
                             if strip:
                                 print('Testing out stripping the RINEX 2 file here')
@@ -221,7 +231,8 @@ def run_rinex2snr(station, year_list, doy_list, isnr, orbtype, rate,dec_rate,arc
                             print('Try to gunzip ', r3gz)
                             subprocess.call(['gunzip', r3gz])
                         if os.path.exists(r3):
-                            print('The RINEX 3 file exists locally')
+                            print('The RINEX 3 file exists locally', r3)
+                            # convert to RINEX 2.11
                             fexists = g.new_rinex3_rinex2(r3,r2,dec_rate)
                             if fexists:
                                 conv2snr(year, doy, station, isnr, orbtype,rate,dec_rate,archive,fortran,translator)
@@ -1086,12 +1097,13 @@ def the_makan_option(station,cyyyy,cyy,cdoy):
     rd = station + cdoy + '0.' + cyy + 'd'
     print(r,rd)
 
-    locdir= os.environ['REFL_CODE'] + '/rinex/' + station + '/' + cyyyy + '/'
+    locdir=  os.environ['REFL_CODE'] + '/rinex/' + station + '/' + cyyyy + '/'
+    locdir2= os.environ['REFL_CODE'] + '/' + cyyyy + '/rinex/' + station + '/'
     #
     #locdir2= os.environ['RINEX'] + station + '/' + cyyyy + '/'
     #locdir3= os.environ['RINEX'] + station.upper() + '/' + cyyyy + '/'
 
-    print('Will look for files in the working directory and ', locdir)
+    print('Will look for files in the working directory and ', locdir )
     # I was testing this ... but have not finished
     #so_many_permutations(r,rd,locdir, crnxpath)
 
@@ -1218,3 +1230,40 @@ def go_from_crxgz_to_rnx(c3gz,deletecrx=True):
             subprocess.call(['rm','-f',c3])
 
     return translated, rnx
+
+def get_local_rinexfile(rfile,localpath2):
+    """
+    look for a plain or gzipped version of the rinex 2.11 file in the year subdirectories
+    copies it to the local directory.  this method stops the code from deleting your rinex 
+    files
+
+    localpath2 =  os.environ['REFL_CODE'] + '/' + cyyyy + '/rinex/' + station + '/'
+
+    Parameters
+    ----------
+    rfile : str
+        version2 rinexfile name
+
+    localpath2 : str
+        location of the file
+
+    Returns
+    -------
+    allgood : bool
+        whether file found
+    """
+    allgood = False
+    r = localpath2 + rfile
+    if os.path.exists(r):
+        allgood = True
+        # cp to the local directory
+        subprocess.call(['cp',r,'.'])
+    else:
+       # did not find noromal rinex, so look for gzip version
+        if os.path.exists(r + '.gz'):
+            subprocess.call(['gunzip', r + '.gz'])
+        if os.path.exists(r):
+            subprocess.call(['cp',r,'.'])
+            allgood = True
+
+    return allgood
