@@ -18,7 +18,7 @@ import scipy.interpolate as interpolate
 from scipy.interpolate import interp1d
 import math
 
-def writeout_spline_outliers(tvd_bad,txtdir,residual):
+def writeout_spline_outliers(tvd_bad,txtdir,residual,filename):
     """
 
     Write splinefit outliers to a file. 
@@ -33,10 +33,13 @@ def writeout_spline_outliers(tvd_bad,txtdir,residual):
 
     residual : numpy array
         outlier in units of meters (!)
+
+    filename : str
+        name of file being written
     """
     nr,nc=tvd_bad.shape
     if nr > 0:
-        f = txtdir + '/outliers.spline.txt'
+        f = txtdir + '/' + filename
         print(nr, ' Outliers written to: ', f)
         fout = open(f, 'w+')
         # put in a header
@@ -86,6 +89,7 @@ def mirror_plot(tnew,ynew,spl_x,spl_y,txtdir,station,beginT,endT):
     plt.xlim((beginT, endT))
     plt.grid()
     g.save_plot(txtdir + '/' + station + '_rhdot1.png')
+    plt.close()
 
 def print_badpoints(t,outliersize,txtdir,real_residuals):
     """
@@ -202,7 +206,7 @@ def write_subdaily(outfile,station,ntv,writecsv,extraline,**kwargs):
     original = False
     if len(RHdot_corr) + len(newRH) + len(newRH_IF) == 0:
         original = True
-        print('Original version of LSP series being written')
+        print('LSP series being written')
     # 
     write_IF_corrected = False
     if len(newRH_IF) > 0:
@@ -334,6 +338,8 @@ def readin_and_plot(station, year,d1,d2,plt2screen,extension,sigma,writecsv,azim
     print('>>>>>>>>>>>>>>>>>>>>>>>> readin RH data <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<')
     if txtfile == '':
         print('Read in the RH retrievals for ', year, ' and these days: ',d1,d2)
+        if len(extension) > 0:
+            print('Using the results in the ', extension , ' subdirectory.')
         if (d2 < d1):
             print('First day of year must be less than last day of year. Exiting')
             sys.exit()
@@ -731,7 +737,8 @@ def two_stacked_plots(otimes,tv,station,txtdir,year,d1,d2):
     # this is not working, so just setting it to false, cause who cares!
     setlimits = False
     fs = 10
-    fig,(ax1,ax2,ax3)=plt.subplots(3,1,sharex=True)
+    fig,(ax1,ax2,ax3)=plt.subplots(3,1,sharex=True,figsize=(10,8))
+    #fig,(ax1,ax2,ax3)=plt.subplots(3,1,sharex=True)
     i = (tv[:,10] < 100)
     colors = tv[:,10]
     scatter = ax1.scatter(otimes,tv[:,2],marker='o', s=10, c=colors)
@@ -821,6 +828,7 @@ def stack_two_more(otimes,tv,ii,jj,stats, station, txtdir, sigma,kplt):
     plt.plot(tv[ii,5],tv[ii,2], 'ro',markersize=4,label='outliers')
     plt.xlabel('Azimuth (degrees)')
     plt.ylabel('Reflector Height (m)')
+    plt.title('Quick Plot of RH with respect to Azimuth')
     plt.gca().invert_yaxis()
     plt.legend(loc="best")
     plt.grid()
@@ -1289,7 +1297,7 @@ def rhdot_correction2(station,fname,fname_new,pltit,outlierV,**kwargs):
 
     kk = np.abs(residual_after) > 3*sigmaAfter
     tvd_confused = tvd[kk,:]
-    writeout_spline_outliers(tvd_confused,txtdir,residual_after[kk])
+    writeout_spline_outliers(tvd_confused,txtdir,residual_after[kk],'outliers.spline.txt')
 
     # keep values within 3 sigma 
     ii = np.abs(residual_after) < 3*sigmaAfter
@@ -1344,7 +1352,7 @@ def rhdot_correction2(station,fname,fname_new,pltit,outlierV,**kwargs):
 
     print('Freq  Bias  Sigma   NumObs ')
     print('       (m)   (m)       ')
-    for f in [1, 2, 20, 5, 20, 101, 102, 201, 205,206,207,208,302,306,307]:
+    for f in [1, 2, 20, 5, 101, 102, 201, 205,206,207,208,302,306,307]:
         ff = (tvd_new[:,10] == f)
         ret = residual_after[ff]
         if len(ret) > 0:
@@ -1363,6 +1371,8 @@ def rhdot_correction2(station,fname,fname_new,pltit,outlierV,**kwargs):
 
     if not apply_if_corr:
         print('You chose not to correct for IF biases. Exiting')
+        if pltit:
+            plt.show()
         return tvd_new, correction
 
     # now try to write the bias corrected values
@@ -1414,7 +1424,7 @@ def rhdot_correction2(station,fname,fname_new,pltit,outlierV,**kwargs):
     # points to keep
     jj = np.abs(biasCor_rh -spline_at_GPS)/newsigma < 3
 
-    plt.plot(th[ii], biasCor_rh[ii], 'rx', label='3-sig outliers' + strsig)
+    plt.plot(th[ii], biasCor_rh[ii], 'rx', label='3-sig outliers')
 
     plt.legend(loc="upper left")
     plt.grid()
@@ -1430,6 +1440,8 @@ def rhdot_correction2(station,fname,fname_new,pltit,outlierV,**kwargs):
     plt.xlabel('days of the year')
 
     plt.plot(th[ii], (biasCor_rh -spline_at_GPS)[ii], 'r.',label='3-sig')
+    # will write these residauls out to a file
+    badpoints2 =  (biasCor_rh -spline_at_GPS)[ii]
     plt.legend(loc="upper left")
 
     print('RMS with frequency bias taken out (m) ', np.round(newsigma,3)  )
@@ -1440,11 +1452,17 @@ def rhdot_correction2(station,fname,fname_new,pltit,outlierV,**kwargs):
     biasCor_rh = tvd_new[jj,24]
     write_subdaily(bias_corrected_filename,station,tvd_new[jj,:], writecsv,extraline, newRH_IF=biasCor_rh)
 
+    new_outliers = tvd_new[ii,:]
+
+    # write outliers again ... 
+    writeout_spline_outliers(new_outliers,txtdir,badpoints2,'outliers.spline2.txt')
+
+
     # I was looking at issue of delT being too big
 
     if splineout:
         if delta_out == 0:
-            print('no spline values are written')
+            print('No spline values will be written')
         else:
             #
             iyear = int(tvd_new[0,0])
@@ -1462,6 +1480,8 @@ def rhdot_correction2(station,fname,fname_new,pltit,outlierV,**kwargs):
             splinefileout =  txtdir + '/' + station + '_' + str(iyear) + '_spline_out.txt'
             print('Writing evenly sampled file to: ', splinefileout)
             fout = open(splinefileout,'w+')
+            fout.write('{0:1s}  {1:30s}  \n'.format('%','This is a spline fit - be careful when interpreting'))
+            fout.write('{0:1s}  {1:30s}  \n'.format('%','MJD, RH(m), YY,MM,DD,HH,MM,SS'))
             dtime = False
             for i in range(0,N):
                 modjul = g.fdoy2mjd(iyear,tplot[i])
